# eepackages

[![PyPi version](https://badgen.net/pypi/v/eepackages/)](https://pypi.com/project/eepackages)

A set of utilities built on top of Google Earth Engine (migrated from JavaScript)

## Usage

## Installation

## Requirements

## Compatibility

## Licence

## Authors

`eepackages` was written by `Gennadii Donchyts <gennadiy.donchyts@gmail.com>`_.

## TODO

- unit testing
- coverage
